@@ -1,11 +1,9 @@
 use strict;
 use warnings;
 package Rubric::CLI::Command::db;
-{
-  $Rubric::CLI::Command::db::VERSION = '0.154';
-}
-use base qw(Rubric::CLI::Command);
 # ABSTRACT: database management
+$Rubric::CLI::Command::db::VERSION = '0.155';
+use parent qw(Rubric::CLI::Command);
 
 use Rubric::DBI::Setup;
 
@@ -45,13 +43,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Rubric::CLI::Command::db - database management
 
 =head1 VERSION
 
-version 0.154
+version 0.155
 
 =head1 AUTHOR
 
