@@ -1,15 +1,31 @@
 use strict;
 use warnings;
 package Rubric::WebApp::Login::HTTP;
-{
-  $Rubric::WebApp::Login::HTTP::VERSION = '0.154';
-}
-use base qw(Rubric::WebApp::Login);
 # ABSTRACT: process web login from HTTP authentication
+$Rubric::WebApp::Login::HTTP::VERSION = '0.155';
+use parent qw(Rubric::WebApp::Login);
 
+# =head1 DESCRIPTION
+#
+# This module checks for information needed to confirm that a user is logged into
+# the Rubric.
+#
+# =head1 METHODS
+#
+# =head2 get_login_username
+#
+# This method returns the REMOTE_USER environment variable.
+#
+# =cut
 
 sub get_login_username { $ENV{REMOTE_USER} }
 
+# =head2 authenticate_login
+#
+# This method always returns true.  (The assumption, here, is that the HTTP
+# server has already taken care of authentication.)
+#
+# =cut
 
 sub authenticate_login { 1 }
 
@@ -19,13 +35,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Rubric::WebApp::Login::HTTP - process web login from HTTP authentication
 
 =head1 VERSION
 
-version 0.154
+version 0.155
 
 =head1 DESCRIPTION
 
